"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_js_1 = require("@visual-regression-tracker/sdk-js");
const playwright_1 = require("playwright");
const _1 = require(".");
const utils_1 = require("ts-jest/utils");
describe("playwright", () => {
    let browserType = playwright_1.chromium;
    let browser;
    let context;
    let page;
    let vrt;
    const config = {
        apiUrl: "http://localhost:4200",
        branchName: "develop",
        projectId: "733c148e-ef70-4e6d-9ae5-ab22263697cc",
        apiKey: "BAZ0EG0PRH4CRQPH19ZKAVADBP9E",
    };
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        browser = yield browserType.launch();
        context = yield browser.newContext({
            viewport: {
                width: 1800,
                height: 1600,
            },
        });
        page = yield context.newPage();
        vrt = new _1.PlaywrightVisualRegressionTracker(config, browserType);
    }));
    afterAll(() => {
        browser.close();
    });
    it("track all fields", () => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b, _c, _d;
        const imageName = "test name";
        const trackOptions = {
            diffTollerancePercent: 12.31,
            agent: {
                os: "OS",
                device: "device ",
            },
            screenshotOptions: {
                fullPage: true,
                clip: {
                    x: 1,
                    y: 2,
                    width: 3,
                    height: 4,
                },
                omitBackground: true,
            },
        };
        const trackMock = jest.fn();
        sdk_js_1.VisualRegressionTracker.prototype.track = trackMock;
        const pageMocked = utils_1.mocked(page);
        const screenshot = new Buffer("image mocked");
        const screenshotMock = jest.fn().mockResolvedValueOnce(screenshot);
        pageMocked.screenshot = screenshotMock;
        yield vrt.track(page, imageName, trackOptions);
        expect(pageMocked.screenshot).toHaveBeenCalledWith(trackOptions.screenshotOptions);
        expect(trackMock).toHaveBeenCalledWith({
            name: imageName,
            imageBase64: screenshot.toString("base64"),
            browser: browserType.name(),
            viewport: `${(_a = page.viewportSize()) === null || _a === void 0 ? void 0 : _a.width}x${(_b = page.viewportSize()) === null || _b === void 0 ? void 0 : _b.height}`,
            os: (_c = trackOptions.agent) === null || _c === void 0 ? void 0 : _c.os,
            device: (_d = trackOptions.agent) === null || _d === void 0 ? void 0 : _d.device,
            diffTollerancePercent: trackOptions.diffTollerancePercent,
        });
    }));
    it("track default fields", () => __awaiter(void 0, void 0, void 0, function* () {
        const imageName = "test name";
        const trackMock = jest.fn();
        sdk_js_1.VisualRegressionTracker.prototype.track = trackMock;
        const pageMocked = utils_1.mocked(page);
        const screenshot = new Buffer("image mocked");
        const screenshotMock = jest.fn().mockResolvedValueOnce(screenshot);
        pageMocked.screenshot = screenshotMock;
        pageMocked.viewportSize = jest.fn().mockReturnValueOnce(null);
        yield vrt.track(page, imageName);
        expect(pageMocked.screenshot).toHaveBeenCalledWith(undefined);
        expect(trackMock).toHaveBeenCalledWith({
            name: imageName,
            imageBase64: screenshot.toString("base64"),
            browser: browserType.name(),
            viewport: undefined,
            os: undefined,
            device: undefined,
            diffTollerancePercent: undefined,
        });
    }));
});
